@@ -22,7 +22,7 @@ Readonly::Scalar my $BLOCK_SIZE => 4_096;
 Readonly::Array my @PAR_SEP => (q{&}, q{;});
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -846,17 +846,17 @@ Common Gateway Interface Class for loading/saving object in file.
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2004-2015 Michal Špaček
+ © 2004-2018 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
